# authentic2 - versatile identity manager
# Copyright (C) 2022 Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django import forms
from django.db.models import Max
from django.utils.translation import ugettext as _

from authentic2.forms.mixins import SlugMixin

from .models import BaseAuthenticator, LoginPasswordAuthenticator


class AuthenticatorsOrderForm(forms.Form):
    order = forms.CharField(widget=forms.HiddenInput)


class AuthenticatorAddForm(SlugMixin, forms.ModelForm):
    field_order = ('authenticator', 'name', 'ou')

    authenticator = forms.ChoiceField(label=_('Authenticator'))

    class Meta:
        model = BaseAuthenticator
        fields = ('name',)

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)

        self.authenticators = {
            x.type: x for x in BaseAuthenticator.__subclasses__() if not x.unique or x.objects.count() < 1
        }
        self.fields['authenticator'].choices = [
            (k, v._meta.verbose_name) for k, v in self.authenticators.items()
        ]

    def save(self):
        max_order = BaseAuthenticator.objects.aggregate(max=Max('order'))['max'] or 0

        Authenticator = self.authenticators[self.cleaned_data['authenticator']]
        self.instance = Authenticator(name=self.cleaned_data['name'], order=max_order + 1)
        return super().save()


class LoginPasswordAuthenticatorEditForm(forms.ModelForm):
    class Meta:
        model = LoginPasswordAuthenticator
        exclude = ('name', 'slug', 'ou', 'button_label')
