# authentic2 - versatile identity manager
# Copyright (C) 2010-2019 Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.conf.urls import url
from django.urls import path

from authentic2.apps.authenticators.manager_urls import superuser_login_required
from authentic2.decorators import required

from . import views

urlpatterns = [
    url(r'^accounts/oidc/login/(?P<pk>\d+)/$', views.oidc_login, name='oidc-login'),
    url(r'^accounts/oidc/login/$', views.login_initiate, name='oidc-login-initiate'),
    url(r'^accounts/oidc/callback/$', views.login_callback, name='oidc-login-callback'),
]

urlpatterns += required(
    superuser_login_required,
    [
        path(
            'authenticators/<int:authenticator_pk>/claim/add/',
            views.add_claim,
            name='a2-manager-oidc-add-claim',
        ),
        path(
            'authenticators/<int:authenticator_pk>/claim/<int:pk>/edit/',
            views.edit_claim,
            name='a2-manager-oidc-edit-claim',
        ),
        path(
            'authenticators/<int:authenticator_pk>/claim/<int:pk>/delete/',
            views.delete_claim,
            name='a2-manager-oidc-delete-claim',
        ),
    ],
)
